Module contract_transcode::env_types
source · Structs
Custom encoding/decoding for the Substrate
AccountId type.Provides custom encoding and decoding for predefined environment types.
Custom decoding for the
Hash or [u8; 32] type so that it is displayed as a hex encoded
string.Traits
Implement this trait to define custom decoding for a type in a
scale-info type registry.Implement this trait to define custom encoding for a type in a
scale-info type registry.