pub struct ContractMessageTranscoder { /* private fields */ }Expand description
Encode strings to SCALE encoded smart contract calls.
Decode SCALE encoded smart contract events and return values into Value objects.
Implementations
sourceimpl ContractMessageTranscoder
impl ContractMessageTranscoder
pub fn new(metadata: InkProject) -> Self
sourcepub fn load<P>(metadata_path: P) -> Result<Self>where
P: AsRef<Path>,
pub fn load<P>(metadata_path: P) -> Result<Self>where P: AsRef<Path>,
Attempt to create a ContractMessageTranscoder from the metadata file at the given path.
pub fn encode<I, S>(&self, name: &str, args: I) -> Result<Vec<u8>>where I: IntoIterator<Item = S>, S: AsRef<str> + Debug,
pub fn decode(&self, type_id: u32, input: &mut &[u8]) -> Result<Value>
pub fn decode_contract_event(&self, data: &mut &[u8]) -> Result<Value>
pub fn decode_contract_message(&self, data: &mut &[u8]) -> Result<Value>
pub fn decode_contract_constructor(&self, data: &mut &[u8]) -> Result<Value>
pub fn decode_return(&self, name: &str, data: &mut &[u8]) -> Result<Value>